@@ -30,12 +30,25 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-$permaId = $App->getParam('id');
-list($bennoId,$permaArchive) = explode('@',base64_decode($permaId),2);
+$permalink = $App->getParam('id');
+
+// decode permalink
+try {
+    $PermaId = new PermaId();
+    list($bennoId,$permaArchive) = $PermaId->decrypt($permalink);
+}
+catch (Exception $e) {
+        $msg = $e->getMessage();
+        $App->log($msg);
+        $App->setMsg($msg);
+        $App->redirect('index.php?CA=default',array('MSG' => $msg));
+}
+
+
 $filterString = "(id:*)";
 
 if ($App->getConfig('PERMALINK_UNAUTHENTICATED') != 'yes') {
-    $App->redirect('index.php?CA=default',array('id' => $permaId));
+    $App->redirect('index.php?CA=default',array('id' => $permalink));
 }
 
 
@@ -49,7 +62,7 @@ $rest_user = $RESTconf->getConfig('REST_USER','benno2');
 $rest_pass = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
 $Backend = new Backend($base_url,$rest_user,$rest_pass,$filterString);
 
-$PermaQuery = new Query($permaId,$permaArchive,$bennoId);
+$PermaQuery = new Query($permalink,$permaArchive,$bennoId);
 $PermaQuery->type = 'RepoPath';
 try {
     // fresh search, thus we start with position 1
@@ -70,8 +83,8 @@ catch (Exception $e) {
 }
 
 // Redirect from Login
-if (!$permaId) {
-    $permaId = $App->getSession('permaId');
+if (!$permalink) {
+    $permalink = $App->getSession('permalink');
     $App->unsetSession('LOGIN_REDIRECT');
 }
 
