@@ -253,7 +253,13 @@ class Backend
                       .$App->getSession('USER')->id;
 
         if (!$this->_curl) {
-            $this->_curl = curl_init();
+            if (extension_loaded('curl')) {
+                $this->_curl = curl_init();
+            }
+            else {
+                $App->log('ERROR: curl module not installed!');
+                throw new Exception('ERR_INTERN');
+            }
         }
         $curl =& $this->_curl;
 
