@@ -82,10 +82,22 @@ class MailObject
         }
     }
 
-    function setDate($date) { $this->date = $date; }
+
+    function setDate($date,$format)
+    {
+
+        if ($date) {
+            $this->date = strftime($format,$date);
+        }
+    }
 
 
-    function setTime($time) { $this->time = $time; }
+    function setTime($time,$format)
+    {
+        if ($time) {
+            $this->time = strftime($format,$time);
+        }
+    }
 
 
     function setError($msg_sym)
