@@ -47,8 +47,10 @@ catch (Exception $e) {
     $App->log($errorMsg);
 }
 
-$permaId = base64_encode($EMail->bennoId.'@'.$EMail->archive);
-$MailObject = new MailObject($EMail->id,$permaId);
+$PermaId = new PermaId();
+$plink = $PermaId->encrypt($EMail->bennoId,$EMail->archive);
+
+$MailObject = new MailObject($EMail->id,$plink);
 $MailObject->from       = $EMail->getFrom();
 $MailObject->to         = $EMail->getTo();
 $MailObject->cc         = $EMail->getCc();
@@ -90,8 +92,8 @@ catch (Exception $e) {
 }
 
 $mailDate = $EMail->getDate();
-$MailObject->setDate(strftime($LOCALE['dateformat'],$mailDate));
-$MailObject->setTime(strftime($LOCALE['timeformat'],$mailDate));
+$MailObject->setDate($mailDate,$LOCALE['dateformat']);
+$MailObject->setTime($mailDate,$LOCALE['timeformat']);
 $MailObject->setBody($body_content,$body_type);
 
 if ($errorMsg) {
